@@ -5,7 +5,7 @@
 
 #include "ecore_con_base.eo.legacy.h"
 #include "ecore_con_server.eo.legacy.h"
-#include "ecore_con_connector.eo.legacy.h"
+#include "efl_network_connector.eo.legacy.h"
 #include "ecore_con_client.eo.legacy.h"
 
 
